cxy_geography: Single GeoLookup

Description Usage Arguments Details Value

View source: R/single.R

Description

Provides access to the GeoLookup API of the US Census Bureau. Returns census geographies for a single geographic point.

Usage

1
2
3
4
5
6
cxy_geography(
  lon,
  lat,
  benchmark = "Public_AR_Current",
  vintage = "Current_Current"
)

Arguments

lon

Numeric or String Containing Longitude (x) of Point

lat

Numeric or String Containing Latitude (y) of Point

benchmark

Optional ID or Name of Census Benchmark. See Details.

vintage

Optional ID or Name of Census Vintage. See Details.

Details

This function can be used to locate geographic information given a geographic point. It does not provide an address like a reverse-geocoder

Value

A data.frame containing matched address or NULL if not matches


slu-openGIS/cxy2 documentation built on March 31, 2020, 10:09 a.m.