Description Usage Format Source Examples
An example data set containing the addresses for homicides reported by the Saint Louis Metropolitan Police Department
1 |
A tibble with 1822 rows and 6 variables:
number, street and street suffix where homicide occured
year homicide occurred
data homicide occurred
state abbreviation of location, in these data, all "MO"
zipcode/postal code of location, in these data all NA
city of location, in these data all "St. Louis"
St. Louis Metropolitan Police Department
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.