Description Usage Arguments Details Value
Provides access to the GeoLookup API of the US Census Bureau. Returns census geographies for a single geographic point.
1 2 3 4 5 6 | cxy_geography(
lon,
lat,
benchmark = "Public_AR_Current",
vintage = "Current_Current"
)
|
lon |
Numeric or String Containing Longitude (x) of Point |
lat |
Numeric or String Containing Latitude (y) of Point |
benchmark |
Optional ID or Name of Census Benchmark. See Details. |
vintage |
Optional ID or Name of Census Vintage. See Details. |
This function can be used to locate geographic information given a geographic point. It does not provide an address like a reverse-geocoder
A data.frame containing matched address or NULL if not matches
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.